==> owncloud-4.5.4.tar.bz2: owncloud/apps/contacts/l10n/zh_CN.GB2312.php <==
<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "激活/取消激活地址薄出错。",
"id is not set." => "未设置 ID。",
"Cannot update addressbook with an empty name." => "不能更新名称为空的地址薄。",
"No ID provided" => "没有提供 ID",
"Error setting checksum." => "设置校验和出错。",
"No categories selected for deletion." => "没有选中要删除的分类。",
"No address books found." => "没有找到地址薄。",
"No contacts found." => "没有找到联系人。",
"element name is not set." => "元素名称未设置。",
"Could not parse contact: " => "未能解析联系人：",
"Cannot add empty property." => "不能添加空属性。",
"At least one of the address fields has to be filled out." => "需填写至少一个地址栏。",
"Trying to add duplicate property: " => "尝试添加重复属性：",
"Missing IM parameter." => "缺失即时通讯参数。",
"Unknown IM: " => "未知即时通讯服务：",
"Information about vCard is incorrect. Please reload the page." => "vCard 信息不正确。请刷新页面。",
"Missing ID" => "缺失 ID",
"Error parsing VCard for ID: \"" => "解析 VCard 出错，ID 是：\"",
"checksum is not set." => "校验和未设置。",
"Information about vCard is incorrect. Please reload the page: " => "vCard 信息不正确。请刷新页面：",
"Something went FUBAR. " => "FUBAR 出错。",
"No contact ID was submitted." => "没有提交联系人 ID。",
"Error reading contact photo." => "读取联系人相片出错。",
"Error saving temporary file." => "保存临时文件出错。",
"The loading photo is not valid." => "载入的相片无效。",
"Contact ID is missing." => "缺失联系人 ID。",
"No photo path was submitted." => "未提交相片路径。",
"File doesn't exist:" => "文件不存在：",
"Error loading image." => "加载相片出错。",
"Error getting contact object." => "获取联系人对象出错。",
"Error getting PHOTO property." => "获取相片属性出错。",
"Error saving contact." => "保存联系人出错。",
"Error resizing image" => "缩放相片出错",
"Error cropping image" => "剪裁相片出错",
"Error creating temporary image" => "创建临时相片出错",
"Error finding image: " => "查找相片出错：",
"Error uploading contacts to storage." => "上传联系人到存储出错。",
"There is no error, the file uploaded with success" => "文件上传成功",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "上传的文件超过了 php.ini 中的 upload_max_filesize 选项",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "上传的文件超过了 HTML 表格中指定的 MAX_FILE_SIZE 选项",
"The uploaded file was only partially uploaded" => "文件部分上传",
"No file was uploaded" => "没有上传文件",
"Missing a temporary folder" => "缺失临时文件夹",
"Couldn't save temporary image: " => "不能保存临时相片：",
"Couldn't load temporary image: " => "不能载入临时相片：",
"No file was uploaded. Unknown error" => "没有上传文件。未知错误",
"Contacts" => "联系人",
"Sorry, this functionality has not been implemented yet" => "对不起，该功能尚未实现",
"Not implemented" => "未实现",
"Couldn't get a valid address." => "未能获取有效地址。",
"Error" => "出错",
"Enter name" => "输入名称",
"Format custom, Short name, Full name, Reverse or Reverse with comma" => "格式自定义，短名称，全名，分隔或用逗号分隔",
"Select type" => "选择类型",
"You do not have permission to add contacts to " => "您没有权限添加联系人到",
"Please select one of your own address books." => "请选择一个您自己的地址薄。",
"Permission error" => "权限错误",
"This property has to be non-empty." => "该属性不能为空。",
"Couldn't serialize elements." => "不能序列化元素",
"'deleteProperty' called without type argument. Please report at bugs.owncloud.org" => "'deleteProperty' 没有带类型参数调用。请到 bugs.owncloud.org 报告",
"Edit name" => "编辑名称",
"No files selected for upload." => "未选择要上传的文件。",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "您试图上传的文件超出了此服务器允许的上传文件最大尺寸。",
"Error loading profile picture." => "加载档案相片出错。",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "一些联系人标记为删除，但尚未删除。请等待它们被删除。",
"Do you want to merge these address books?" => "您想要合并这些地址薄吗？",
"Upload too large" => "上传过大",
"Unable to upload your file as it is a directory or has 0 bytes" => "不能上传您的文件，由于它是文件夹或者为空文件",
"Upload Error" => "上传错误",
"Pending" => "等待中",
"Import done" => "导入完成",
"Not all files uploaded. Retrying..." => "有文件未上传。重试中...",
"Something went wrong with the upload, please retry." => "上传出错，请重试。",
"Importing..." => "导入中...",
"The address book name cannot be empty." => "地址薄名称不能为空。",
"Result: " => "结果：",
" imported, " => "已导入，",
" failed." => "失败。",
"Displayname cannot be empty." => "显示名称不能为空。",
"Show CardDav link" => "显示 CardDav 链接",
"Show read-only VCF link" => "显示只读 VCF 链接",
"Download" => "下载",
"Edit" => "编辑",
"Delete" => "删除",
"Cancel" => "取消",
"More..." => "更多...",
"You do not have the permissions to read this addressbook." => "您没有权限读取此地址薄。",
"You do not have the permissions to update this addressbook." => "您没有权限更新此地址薄。",
"There was an error updating the addressbook." => "更新地址薄出错。",
"You do not have the permissions to delete this addressbook." => "您没有权限删除此地址薄。",
"There was an error deleting this addressbook." => "删除此地址薄出错。",
"Addressbook not found: " => "未找到地址薄：",
"This is not your addressbook." => "这不是您的地址薄",
"Contact could not be found." => "找不到联系人。",
"Jabber" => "Jabber",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "推特",
"GoogleTalk" => "Google Talk",
"Facebook" => "脸书",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "雅虎",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "单位",
"Home" => "家庭",
"Other" => "其他",
"Mobile" => "手机",
"Text" => "文本",
"Voice" => "声音",
"Message" => "信息",
"Fax" => "传真",
"Video" => "视频",
"Pager" => "分页",
"Internet" => "互联网",
"Birthday" => "生日",
"Business" => "商业",
"Call" => "呼叫",
"Clients" => "客户",
"Deliverer" => "供应商",
"Holidays" => "假日",
"Ideas" => "想法",
"Journey" => "路程",
"Jubilee" => "娱乐",
"Meeting" => "会议",
"Personal" => "私人",
"Projects" => "项目",
"Questions" => "问题",
"{name}'s Birthday" => "{name} 的生日",
"Contact" => "联系人",
"You do not have the permissions to add contacts to this addressbook." => "您没有权限添加联系人到此地址薄。",
"Could not find the vCard with ID." => "未能找到此 ID 的 vCard。",
"You do not have the permissions to edit this contact." => "您没有权限编辑此联系人。",
"Could not find the vCard with ID: " => "未能找到 vCard，ID 是：",
"Could not find the Addressbook with ID: " => "未能找到地址薄，ID 是：",
"You do not have the permissions to delete this contact." => "您没有权限删除此联系人。",
"There was an error deleting this contact." => "删除联系人出错。",
"Add Contact" => "添加联系人",
"Import" => "导入",
"Settings" => "设置",
"Close" => "关闭",
"Keyboard shortcuts" => "热键",
"Navigation" => "导航",
"Next contact in list" => "列表中下一个联系人",
"Previous contact in list" => "列表中上一个联系人",
"Expand/collapse current addressbook" => "展开/收缩当前地址薄",
"Next addressbook" => "下一个地址薄",
"Previous addressbook" => "前一个地址薄。",
"Actions" => "操作",
"Refresh contacts list" => "刷新联系人列表",
"Add new contact" => "添加新联系人",
"Add new addressbook" => "添加新地址薄",
"Delete current contact" => "删除当前联系人",
"Drop photo to upload" => "拖拽相片上传",
"Delete current photo" => "删除当前相片",
"Edit current photo" => "编辑当前相片",
"Upload new photo" => "上传新相片",
"Select photo from ownCloud" => "从 ownCloud 选择相片",
"Edit name details" => "编辑名称细节",
"Organization" => "组织",
"Nickname" => "昵称",
"Enter nickname" => "输入昵称",
"Web site" => "网站",
"http://www.somesite.com" => "http://www.somesite.com",
"Go to web site" => "访问网站",
"dd-mm-yyyy" => "dd-mm-yyyy",
"Groups" => "群组",
"Separate groups with commas" => "用逗号分隔群组",
"Edit groups" => "编辑群组",
"Preferred" => "偏好",
"Please specify a valid email address." => "请指定有效的电子邮件地址。",
"Enter email address" => "输入电子邮件地址",
"Mail to address" => "向此地址发送邮件",
"Delete email address" => "删除电子邮件地址",
"Enter phone number" => "输入电话号码",
"Delete phone number" => "删除电话号码",
"Instant Messenger" => "即时通讯",
"Delete IM" => "删除即时通讯",
"View on map" => "查看地图",
"Edit address details" => "编辑地址细节",
"Add notes here." => "在此添加备注。",
"Add field" => "添加字段",
"Phone" => "电话",
"Email" => "电子邮件",
"Instant Messaging" => "即时通讯",
"Address" => "地址",
"Note" => "备注",
"Download contact" => "下载联系人",
"Delete contact" => "删除联系人",
"The temporary image has been removed from cache." => "临时相片已从缓存中移除。",
"Edit address" => "编辑地址",
"Type" => "类型",
"PO Box" => "信箱",
"Street address" => "街道地址",
"Street and number" => "街道和门牌号",
"Extended" => "扩展",
"Apartment number etc." => "公寓号等。",
"City" => "城市",
"Region" => "地区",
"E.g. state or province" => "例如，州或省",
"Zipcode" => "邮编",
"Postal code" => "邮编",
"Country" => "国家",
"Addressbook" => "地址薄",
"Hon. prefixes" => "荣誉头衔",
"Miss" => "小姐",
"Ms" => "小姐",
"Mr" => "先生",
"Sir" => "先生",
"Mrs" => "女士",
"Dr" => "博士",
"Given name" => "名",
"Additional names" => "中间名",
"Family name" => "姓",
"Hon. suffixes" => "荣誉头衔",
"J.D." => "法学博士",
"M.D." => "医学博士",
"D.O." => "骨科医学博士",
"D.C." => "脊骨神经科博士",
"Ph.D." => "物理学博士",
"Esq." => "律师",
"Jr." => "初级",
"Sn." => "高级",
"Import a contacts file" => "导入联系人文件",
"Please choose the addressbook" => "请选择地址薄",
"create a new addressbook" => "创建新联系人",
"Name of new addressbook" => "新地址薄名称",
"Importing contacts" => "导入联系人",
"<h3>You have no contacts in your addressbook.</h3><p>You can import VCF files by dragging them to the contacts list and either drop them on an addressbook to import into it, or on an empty spot to create a new addressbook and import into that.<br />You can also import by clicking on the import button at the bottom of the list.</p>" => "<h3>您的地址薄里没有联系人。</h3><p>您可以拖动 VCF 到联系人列表来导入它，拖动到地址薄上将导入到该地址薄中，拖动到空白位置将创建一个新地址薄并导入。<br/>您也可以点击列表底部的导入按钮来导入。</p>",
"Add contact" => "添加联系人",
"Select Address Books" => "选择地址薄",
"Enter description" => "输入描述",
"CardDAV syncing addresses" => "CardDAV 同步地址",
"more info" => "更多信息",
"Primary address (Kontact et al)" => "主要地址 (Kontact 等)",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "地址薄",
"Share" => "分享",
"New Address Book" => "新地址薄",
"Name" => "名称",
"Description" => "描述",
"Save" => "保存"
);

==> owncloud_7.0.4+dfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/zh_CN.GB2312.php <==
<?php $TRANSLATIONS = array(
"Error getting contact object." => "获取联系人对象出错。",
"Error reading contact photo." => "读取联系人相片出错。",
"Error saving temporary file." => "保存临时文件出错。",
"The loading photo is not valid." => "载入的相片无效。",
"No contact info was submitted." => "无联系人信息被提交。",
"No photo path was submitted." => "未提交相片路径。",
"File doesn't exist:" => "文件不存在：",
"Error loading image." => "加载相片出错。",
"Error getting PHOTO property." => "获取相片属性出错。",
"Error saving contact." => "保存联系人出错。",
"Error resizing image" => "缩放相片出错",
"Error cropping image" => "剪裁相片出错",
"Error creating temporary image" => "创建临时相片出错",
"Error finding image: " => "查找相片出错：",
"No file was uploaded. Unknown error" => "没有上传文件。未知错误",
"There is no error, the file uploaded with success" => "文件上传成功",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "上传的文件超过了 php.ini 中的 upload_max_filesize 选项",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "上传的文件超过了 HTML 表格中指定的 MAX_FILE_SIZE 选项",
"The uploaded file was only partially uploaded" => "文件部分上传",
"No file was uploaded" => "没有上传文件",
"Missing a temporary folder" => "缺失临时文件夹",
"Failed to write to disk" => "写磁盘失败",
"Not enough storage available" => "容量不足",
"Error uploading contacts to storage." => "上传联系人到存储出错。",
"Couldn't save temporary image: " => "不能保存临时相片：",
"Couldn't load temporary image: " => "不能载入临时相片：",
"Contacts" => "联系人",
"Save" => "保存",
"Uploading..." => "上传中...",
"Importing..." => "导入中...",
"Error." => "错误",
"Invalid URL: \"{url}\"" => "无效的网址: \"{url}\"",
"Invalid email: \"{url}\"" => "无效的电子邮件: \"{url}\"",
"Select photo" => "选择相片",
"Cancel" => "取消",
"OK" => "好",
"No files selected for upload." => "未选择要上传的文件。",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "您试图上传的文件超出了此服务器允许的上传文件最大尺寸。",
"Error loading profile picture." => "加载档案相片出错。",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "一些联系人标记为删除，但尚未删除。请等待它们被删除。",
"Add" => "添加",
"Result: " => "结果：",
" imported, " => "已导入，",
" failed." => "失败。",
"Error" => "出错",
"Displayname cannot be empty." => "显示名称不能为空。",
"Show CardDav link" => "显示 CardDav 链接",
"Show read-only VCF link" => "显示只读 VCF 链接",
"Download" => "下载",
"Edit" => "编辑",
"Delete" => "删除",
"More..." => "更多...",
"Less..." => "更少...",
"Unknown IM: " => "未知即时通讯服务：",
"Information about vCard is incorrect. Please reload the page." => "vCard 信息不正确。请刷新页面。",
"{name}'s Birthday" => "{name} 的生日",
"Contact" => "联系人",
"Other" => "其他",
"Jabber" => "Jabber",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "推特",
"GoogleTalk" => "Google Talk",
"Facebook" => "脸书",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "雅虎",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "单位",
"Home" => "家庭",
"Mobile" => "手机",
"Text" => "文本",
"Voice" => "声音",
"Message" => "信息",
"Fax" => "传真",
"Video" => "视频",
"Pager" => "分页",
"Internet" => "互联网",
"Import" => "导入",
"Groups" => "群组",
"Close" => "关闭",
"Keyboard shortcuts" => "热键",
"Navigation" => "导航",
"Next contact in list" => "列表中下一个联系人",
"Previous contact in list" => "列表中上一个联系人",
"Expand/collapse current addressbook" => "展开/收缩当前地址薄",
"Next addressbook" => "下一个地址薄",
"Previous addressbook" => "前一个地址薄。",
"Actions" => "操作",
"Refresh contacts list" => "刷新联系人列表",
"Add new contact" => "添加新联系人",
"Add new addressbook" => "添加新地址薄",
"Delete current contact" => "删除当前联系人",
"Add contact" => "添加联系人",
"Delete current photo" => "删除当前相片",
"Edit current photo" => "编辑当前相片",
"Upload new photo" => "上传新相片",
"Select photo from ownCloud" => "从 ownCloud 选择相片",
"Additional names" => "中间名",
"Nickname" => "昵称",
"Enter nickname" => "输入昵称",
"Title" => "头衔",
"Organization" => "组织",
"Birthday" => "生日",
"Phone" => "电话",
"Email" => "电子邮件",
"Instant Messaging" => "即时通讯",
"Address" => "地址",
"Note" => "备注",
"Web site" => "网站",
"Delete contact" => "删除联系人",
"Preferred" => "偏好",
"Please specify a valid email address." => "请指定有效的电子邮件地址。",
"Mail to address" => "向此地址发送邮件",
"Delete email address" => "删除电子邮件地址",
"Enter phone number" => "输入电话号码",
"Delete phone number" => "删除电话号码",
"Go to web site" => "访问网站",
"View on map" => "查看地图",
"Street address" => "街道地址",
"Postal code" => "邮编",
"City" => "城市",
"Country" => "国家",
"Instant Messenger" => "即时通讯",
"Delete IM" => "删除即时通讯",
"Share" => "分享",
"Export" => "导出",
"The temporary image has been removed from cache." => "临时相片已从缓存中移除。",
"CardDAV syncing addresses" => "CardDAV 同步地址",
"more info" => "更多信息",
"Primary address (Kontact et al)" => "主要地址 (Kontact 等)",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "地址薄",
"New Address Book" => "新地址薄",
"Name" => "名称",
"Description" => "描述"
);
